Crate deepseek_tools

Crate deepseek_tools 

Structs

ConfiguredToolSpec
ToolCall
ToolCallRuntime
ToolInvocation
ToolRegistry
ToolResult
Result of a tool execution.
ToolSpec

Enums

ApprovalRequirement
Approval requirement for a tool.
FunctionCallError
ToolCallSource
ToolCapability
Capabilities that a tool may have or require.
ToolError
Errors that can occur during tool execution.

Traits

ToolHandler

Functions

optional_bool
Helper to extract an optional bool field with default.
optional_str
Helper to extract an optional string field from JSON input.
optional_u64
Helper to extract an optional u64 field with default.
required_str
Helper to extract a required string field from JSON input.
required_u64
Helper to extract a required u64 field from JSON input.