Structs
- Configured
Tool Spec - Tool
Call - Tool
Call Runtime - Tool
Invocation - Tool
Registry - Tool
Result - Result of a tool execution.
- Tool
Spec
Enums
- Approval
Requirement - Approval requirement for a tool.
- Function
Call Error - Tool
Call Source - Tool
Capability - Capabilities that a tool may have or require.
- Tool
Error - Errors that can occur during tool execution.
Traits
Functions
- optional_
bool - Helper to extract an optional bool field with default.
- optional_
str - Helper to extract an optional string field from JSON input.
- optional_
u64 - Helper to extract an optional u64 field with default.
- required_
str - Helper to extract a required string field from JSON input.
- required_
u64 - Helper to extract a required u64 field from JSON input.